static char *xpm_font[] = {
" 5 24 3 1",
"  c None",
"# c Black",
"     ",
"     ",
"#####",
"  #  ",
"  #  ",
"  #  ",
"  #  ",
"  #  ",
"  #  ",
"     ",
"     ",
"    #",
" ### ",
"#    ",
"     ",
" ####",
"# #  ",
"  #  ",
"  #  ",
"  #  ",
"  #  ",
" #   ",
"     ",
"     "
};
static char *xpm_color[7][27] = {
{
" 3 24 3 1",
"  c None",
"# c Black",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Blue",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Green",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Cyan",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Red",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Magenta",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
},
{
" 3 24 3 1",
"  c None",
"# c Yellow",
"   ",
"   ",
"   ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
" # ",
"   ",
"   "
}
};
static char *xpm_mark[] = {
"24 24 3 1",
"  c None",
"# c #0000A0",
". c #505000",
"                        ",
"                        ",
"                        ",
" ...  ...  ...  ...     ",
" .                .     ",
" .         #      .     ",
"         #   #          ",
"       #       #        ",
" .   #           #.     ",
" . #              .#    ",
" . #              .#    ",
"   #               #    ",
"   #               #    ",
"   #               #    ",
" . #              .#    ",
" .   #           #.     ",
" .     #       #  .     ",
"         #   #          ",
"           #            ",
" .                .     ",
" .                .     ",
" ...  ...  ...  ...     ",
"                        ",
"                        "
};
static char *xpm_rot[] = {
"24 24 2 1",
"  c None",
"# c #0000A0",
"                        ",
"                        ",
"                        ",
"         #####          ",
"       ##     ##        ",
"     ##         ##      ",
"     #           #      ",
"    #             #     ",
"    #             #     ",
"   #            #  #    ",
"   #             # #    ",
"   #             ###    ",
"   #              ##    ",
"   #              ##    ",
"    #              #    ",
"    #                   ",
"     #                  ",
"     ##                 ",
"       ##               ",
"         ####           ",
"                        ",
"                        ",
"                        ",
"                        "
};
static char *xpm_mov[] = {
"24 24 3 1",
"  c None",
". c #505000",
"# c #0000A0",
"                        ",
"                        ",
"                        ",
"           ..           ",
"         ..  ..         ",
"        . .  . .        ",
"          .  .          ",
"          .  .          ",
"     .            .     ",
"    .    ######    .    ",
"    .... #    # ....    ",
"   .     #    #     .   ",
"   .     #    #     .   ",
"    .... #    # ....    ",
"    .    ######    .    ",
"     .            .     ",
"          .  .          ",
"          .  .          ",
"        . .  . .        ",
"         ..  ..         ",
"           ..           ",
"                        ",
"                        ",
"                        "
};
static char *xpm_copy[] = {
"24 24 3 1",
". c #505000",
"# c #0000A0",
"  c None",
"                        ",
"                        ",
"                        ",
"       .                ",
"     .   .              ",
"    .     .             ",
"   .   .   .            ",
"   .    .  .            ",
"   .     . .            ",
"   .      ..            ",
"   .       .    #       ",
"    .     . . #   #     ",
"     .   .   .     #    ",
"       .    # .  .  #   ",
"            #  . .  #   ",
"            #   ..  #   ",
"            # ....  #   ",
"            #       #   ",
"             #     #    ",
"              #   #     ",
"                #       ",
"                        ",
"                        ",
"                        "
};
static char *xpm_scale[] = {
"24 24 3 1",
". c #505000",
"# c #0000A0",
"  c None",
"                        ",
"   .                    ",
"  . .                   ",
"  . .                   ",
"   .   .                ",
"      . .               ",
"     .   .              ",
"     .   .              ",
"     .   .              ",
"     .   .              ",
"      . .      #        ",
"       .     #   #      ",
"            #     #     ",
"           #       #    ",
"           #       #    ",
"           #       #    ",
"           #       #    ",
"           #       #    ",
"            #     #     ",
"             #   #      ",
"               #        ",
"                        ",
"                        ",
"                        "
};
static char *xpm_clean[] = {
"24 24 3 1",
"  c None",
"# c #0000A0",
". c #505000",
"                        ",
"                        ",
"                        ",
"                        ",
"          #             ",
"          #             ",
"         #              ",
"         #              ",
"        #               ",
"        #               ",
"       #                ",
"       #         ....   ",
"      #   ######....##  ",
"      #   #     .....#  ",
"     #    #      .....  ",
"     #     #      ....  ",
" ######### #     ...#   ",
" # # # # #  #      #    ",
"# # # # # #  ######     ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        "
};
static char *xpm_horiz[] = {
"24 24 3 1",
"  c None",
". c #505000",
"# c #0000A0",
"                        ",
"                        ",
"                        ",
"           ..           ",
"                        ",
"           ..           ",
"         ##  ##         ",
"       ##  ..  ##       ",
"      #          #      ",
"   # #     ..     # #   ",
"   ##              ##   ",
"   ## #    ..    # ##   ",
"   ###            ###   ",
"   ##      ..      ##   ",
"   #                #   ",
"           ..           ",
"                        ",
"           ..           ",
"                        ",
"           ..           ",
"                        ",
"           ..           ",
"                        ",
"                        "
};
static char *xpm_vert[] = {
"24 24 3 1",
"  c None",
"# c #0000A0",
". c #505000",
"                        ",
"                        ",
"                        ",
"         ######         ",
"          ####          ",
"           #  #         ",
"            #  #        ",
"                #       ",
"                #       ",
"                 #      ",
"                 #      ",
"  . . . . . . . . . .   ",
"  . . . . . . . . . .   ",
"                 #      ",
"                 #      ",
"                #       ",
"                #       ",
"            #  #        ",
"           #  #         ",
"          ####          ",
"         ######         ",
"                        ",
"                        ",
"                        "
};
static char *xpm_bracket[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"  ####          ####    ",
"  #       ..       #    ",
"  #      .  .      #    ",
"  #     .    .     #    ",
"  #    .      .    #    ",
"  #   .        .   #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #   .        .   #    ",
"  #    .      .    #    ",
"  #     .    .     #    ",
"  #      .  .      #    ",
"  #       ..       #    ",
"  #                #    ",
"  #                #    ",
"  ####          ####    ",
"                        ",
"                        "
};
static char *xpm_r_bracket[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"    ##          ##      ",
"   #      ..      #     ",
"  #      .  .      #    ",
"  #     .    .     #    ",
"  #    .      .    #    ",
"  #   .        .   #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #   .        .   #    ",
"  #    .      .    #    ",
"  #     .    .     #    ",
"  #      .  .      #    ",
"  #       ..       #    ",
"  #                #    ",
"   #              #     ",
"    ##          ##      ",
"                        ",
"                        "
};
static char *xpm_brace[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"    ##          ##      ",
"   #      ..      #     ",
"  #      .  .      #    ",
"  #     .    .     #    ",
"  #    .      .    #    ",
"  #   .        .   #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
" #   .          .   #   ",
"#    .          .    #  ",
" #   .          .   #   ",
"  #  .          .  #    ",
"  #   .        .   #    ",
"  #    .      .    #    ",
"  #     .    .     #    ",
"  #      .  .      #    ",
"  #       ..       #    ",
"  #                #    ",
"   #              #     ",
"    ##          ##      ",
"                        ",
"                        "
};
static char *xpm_box1[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"  ##################    ",
"  #       ..       #    ",
"  #      .  .      #    ",
"  #     .    .     #    ",
"  #    .      .    #    ",
"  #   .        .   #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #   .        .   #    ",
"  #    .      .    #    ",
"  #     .    .     #    ",
"  #      .  .      #    ",
"  #       ..       #    ",
"  #                #    ",
"  #                #    ",
"  ##################    ",
"                        ",
"                        "
};
static char *xpm_box2[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"  ##################    ",
"  #       ..       #    ",
"  #      .  .      ##   ",
"  #     .    .     ##   ",
"  #    .      .    ##   ",
"  #   .        .   ##   ",
"  #  .          .  ##   ",
"  #  .          .  ##   ",
"  #  .          .  ##   ",
"  #  .          .  ##   ",
"  #  .          .  ##   ",
"  #  .          .  ##   ",
"  #   .        .   ##   ",
"  #    .      .    ##   ",
"  #     .    .     ##   ",
"  #      .  .      ##   ",
"  #       ..       ##   ",
"  #                ##   ",
"  #                ##   ",
"  ###################   ",
"    #################   ",
"                        "
};
static char *xpm_box3[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"  ##################    ",
"  #       ..       ##   ",
"  #      .  .      ###  ",
"  #     .    .     ###  ",
"  #    .      .    ###  ",
"  #   .        .   ###  ",
"  #  .          .  ###  ",
"  #  .          .  ###  ",
"  #  .          .  ###  ",
"  #  .          .  ###  ",
"  #  .          .  ###  ",
"  #  .          .  ###  ",
"  #   .        .   ###  ",
"  #    .      .    ###  ",
"  #     .    .     ###  ",
"  #      .  .      ###  ",
"  #       ..       ###  ",
"  #                ###  ",
"  #                ###  ",
"  ####################  ",
"   ###################  ",
"     #################  "
};
static char *xpm_box4[] = {
"24 24 3 1",
"  c None",
". c #0000A0",
"# c #505000",
"                        ",
"                        ",
"    ##############      ",
"   #       ..     #     ",
"  #      .  .      #    ",
"  #     .    .     #    ",
"  #    .      .    #    ",
"  #   .        .   #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #  .          .  #    ",
"  #   .        .   #    ",
"  #    .      .    #    ",
"  #     .    .     #    ",
"  #      .  .      #    ",
"  #       ..       #    ",
"  #                #    ",
"   #              #     ",
"    ##############      ",
"                        ",
"                        "
};
static const char * xpm_hex[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"           .            ",
"         .   .          ",
"       .       .        ",
"     .           .      ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"     .           .      ",
"       .       .        ",
"         .   .          ",
"           .            ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};

static const char * xpm_pent1[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"             .          ",
"          .   .         ",
"        .      .        ",
"      .         .       ",
"   .             .      ",
"   .              .     ",
"   .               .    ",
"   .                .   ",
"   .                 .  ",
"   .                .   ",
"   .               .    ",
"   .              .     ",
"   .             .      ",
"      .         .       ",
"        .      .        ",
"          .   .         ",
"             .          ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
static const char * xpm_pent2[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"           .            ",
"         .   .          ",
"       .       .        ",
"     .           .      ",
"   .               .    ",
"  .                 .   ",
"  .                 .   ",
"   .               .    ",
"   .               .    ",
"    .             .     ",
"    .             .     ",
"     .           .      ",
"     .           .      ",
"      .         .       ",
"      .         .       ",
"       .........        ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
/*
static const char * xpm_hept[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"           .            ",
"         ..  ..         ",
"      ..       ..       ",
"     .           .      ",
"     .           .      ",
"    .             .     ",
"    .             .     ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"    .             .     ",
"     .           .      ",
"      .         .       ",
"       .       .        ",
"        .......         ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
*/
static const char * xpm_octa[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"        .......         ",
"       .       .        ",
"      .         .       ",
"     .           .      ",
"    .             .     ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"   .               .    ",
"    .             .     ",
"     .           .      ",
"      .         .       ",
"       .       .        ",
"        .......         ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
static const char * xpm_spline[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"             ..         ",
"             ..         ",
"           ...          ",
"      .. ..   .         ",
"      ...      .        ",
"      .        .        ",
"     .          .       ",
"    .            .      ",
"    .            ...    ",
"  ...             ..    ",
"  ..                    ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
static const char * xpm_ltext[] = {
"24 24 3 1",
"       c None",
".      c #505000",
"X      c #FFFFFFFFFFFF",
"                        ",
"                        ",
"   ............         ",
"                        ",
"   .......              ",
"                        ",
"   .........            ",
"                        ",
"   ............         ",
"                        ",
"   ......               ",
"                        ",
"   ...............      ",
"                        ",
"   ........             ",
"                        ",
"   ....                 ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};

static const char * xpm_mtext[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"      ............      ",
"                        ",
"         ......         ",
"                        ",
"     ..............     ",
"                        ",
"      ...........       ",
"                        ",
"          ....          ",
"                        ",
"     ..............     ",
"                        ",
"         ......         ",
"                        ",
"          ....          ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};
static const char * xpm_rtext[] = {
"24 24 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"         ............   ",
"                        ",
"              .......   ",
"                        ",
"            .........   ",
"                        ",
"         ............   ",
"                        ",
"                .....   ",
"                        ",
"      ...............   ",
"                        ",
"            .........   ",
"                        ",
"                 ....   ",
"                        ",
"                        ",
"                        ", 
"                        ",
"                        ",
"                        ",
"                        "};

static const char * xpm_bond[20][12] = {
{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"                        ",
"   ..................   ",
"                        ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"      ............      ",
"                        ",
"   ..................   ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"   ..................   ",
"                        ",
"      ............      ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"      ............      ",
"                        ",
"   ..................   ",
"                        ",
"      ............      ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                 ....   ",
"             ........   ",
"        .............   ",
"   ..................   ",
"        .............   ",
"             ........   ",
"                 ....   ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                   ..   ",
"               ..  ..   ",
"           ..  ..  ..   ",
"   ..  ..  ..  ..  ..   ",
"           ..  ..  ..   ",
"               ..  ..   ",
"                   ..   ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"      ....              ",
"     ..  ..             ",
"   ..      ..      ..   ",
"             ..  ..     ",
"              ....      ",
"                        ",
"                        "

},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                 ..     ",
"                 ...    ",
"   ..................   ",
"                        ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                 ..     ",
"                 ...    ",
"   ..................   ",
"                 ...    ",
"                 ..     ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"   ..................   ",
"   ..................   ",
"   ..................   ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"          .....         ",
"        ..     ..       ",
"       ..       ..      ",
"       .         .      ",
"       ..       ..      ",
"        ..     ..       ",
"          .....         ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"   ..  .. ..  ..  ..    ",
"   ..  .. ..  ..  ..    ",
"   ..  .. ..  ..  ..    ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"       .                ",
"        .               ",
"                        ",
"   .................    ",
"                        ",
"            .           ",
"             .          ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"      ...  ..  ...      ",
"                        ",
"   ..................   ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"                        ",
"   ..................   ",
"                        ",
"      ...  ..  ...      ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"   ..  ..  ..  ..       ",
"   ..  ..  ..  ..       ",
"   ..  ..  ..  ..       ",
"   ..  ..  ..  ..       ",
"   ..  ..  ..  ..       ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"       ........         ",
"      .        .        ",
"     .          ...     ",
"    .            ..     ",
"   .              .     ",
"                        ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        ",
"                        "
},{
"24 9 2 1",
"       c None",
".      c #505000",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        ",
"   ..................   ",
"                        "
}};
